#
# spec file for package perl-Proc-Fork
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Proc-Fork
Name:           perl-Proc-Fork
Version:        0.808
Release:        1.7
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Simple, intuitive interface to the fork() system call
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/A/AR/ARISTOTLE/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Exporter::Tidy)
Requires:       perl(Exporter::Tidy)
%{perl_requires}

%description
This module provides an intuitive, Perl-ish way to write forking programs
by letting you use blocks to illustrate which code section executes in
which fork. The code for the parent, child, retry handler and error handler
are grouped together in a "fork block". The clauses may appear in any
order, but they must be consecutive (without any other statements in
between).

All four clauses need not be specified. If the retry clause is omitted,
only one fork will be attempted. If the error clause is omitted the program
will die with a simple message if it can't retry. If the parent or child
clause is omitted, the respective (parent or child) process will start
execution after the final clause. So if one or the other only has to do
some simple action, you need only specify that one. For example:

 # spawn off a child process to do some simple processing
 run_fork { child {
     exec '/bin/ls', '-l';
     die "Couldn't exec ls: $!\n";
 } };
 # Parent will continue execution from here
 # ...

If the code in any of the clauses does not die or exit, it will continue
execution after the fork block.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Sun Sep  4 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.808
  see /usr/share/doc/packages/perl-Proc-Fork/Changes
  0.808 Wed 10 Aug 2022
  - No functional changes
  - Touched by the spirit of Kakehashi
  - Updated packaging
* Thu Aug 11 2022 Tina Müller <timueller+perl@suse.de>
- updated to 0.807
  see /usr/share/doc/packages/perl-Proc-Fork/Changes
  0.807 Wed 10 Aug 2022
  - No functional changes
  - Packaging fix to stop installing boilerplate.pl
  - Updated package metadata
* Sat Aug 25 2018 coolo@suse.com
- updated to 0.806
  see /usr/share/doc/packages/perl-Proc-Fork/Changes
  0.806 Fri 24 Aug 2018
  - No functional changes
  - Documentation server example fix, spotted by Shoichi Kaji
* Wed Aug 22 2018 coolo@suse.com
- updated to 0.805
  see /usr/share/doc/packages/perl-Proc-Fork/Changes
  0.805 Tue 21 Aug 2018
  - No functional changes
  - No compile test and no test dependencies any more
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.804
  see /usr/share/doc/packages/perl-Proc-Fork/Changes
* Mon Jun 10 2013 coolo@suse.com
- updated to 0.802
  No monkeying with C<bless>, also dropped dependencies on Object::Tiny::Lvalue and Scalar::Util.
  Figured out how to add the credit to Eric Roode for the docs back into the POD under Pod::Weaver.
  All operation and error checking is now in a single function.
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Mon Jan 25 2010 anicka@suse.cz
- update to 0.71
  * Completely new internal structure; modified API, now with a
  C<run_fork> wrapper.
  * L<Exporter::Tidy> replaces some local code.
  * POD examples extracted and provided as files in an F<eg/> directory.
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Feb 26 2007 pkirsch@suse.de
- initial package
